==> haskell-rfc5051-0.1.0.4-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rfc5051.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rfc5051
version:              0.1.0.4
visibility:           public
id:                   rfc5051-0.1.0.4-7swL3USZO9RAWWpLSvaCy1
key:                  rfc5051-0.1.0.4-7swL3USZO9RAWWpLSvaCy1
license:              BSD-3-Clause
copyright:            (C) 2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Simple unicode collation as per RFC5051.
description:
    This library implements @i;unicode-casemap@,
    the simple, non locale-sensitive unicode collation
    algorithm described in RFC 5051 (<http://www.rfc-editor.org/rfc/rfc5051.txt>).
    Proper unicode collation can be done using text-icu, but that is a big
    dependency that depends on a large C library, and rfc5051 might be better
    for some purposes.

    Here is a list of strings sorted by the Prelude'\''s @sort@ function:
    @Abe Oeb abe ab&#233; oeb &#193;be &#196;be &#212;eb &#225;be &#228;be &#244;eb@.

    Here is the same list sorted by @sortBy compareUnicode@:

    @Abe abe ab&#233; &#193;be &#225;be &#196;be &#228;be Oeb oeb &#212;eb &#244;eb@

category:             Text
abi:                  7df68695eec2865abed4983333e8e8e5
exposed:              True
exposed-modules:      Data.RFC5051
hidden-modules:       Data.RFC5051.UnicodeData Data.RFC5051.Types
import-dirs:          /usr/lib/ghc-8.10.1/site-local/rfc5051-0.1.0.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/rfc5051-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/rfc5051-0.1.0.4
hs-libraries:         HSrfc5051-0.1.0.4-7swL3USZO9RAWWpLSvaCy1
depends:              base-4.14.0.0 bytestring-0.10.10.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-rfc5051/html/rfc5051.haddock
haddock-html:         /usr/share/doc/haskell-rfc5051/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rfc5051-0.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rfc5051.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rfc5051
version:              0.2
visibility:           public
id:                   rfc5051-0.2-7aXx1NTcmt9orSpjH8Jed
key:                  rfc5051-0.2-7aXx1NTcmt9orSpjH8Jed
license:              BSD-3-Clause
copyright:            (C) 2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Simple unicode collation as per RFC5051.
description:
    This library implements @i;unicode-casemap@,
    the simple, non locale-sensitive unicode collation
    algorithm described in RFC 5051 (<http://www.rfc-editor.org/rfc/rfc5051.txt>).
    Proper unicode collation can be done using text-icu, but that is a big
    dependency that depends on a large C library, and rfc5051 might be better
    for some purposes.

    Here is a list of strings sorted by the Prelude'\''s @sort@ function:

    Abe Oeb abe ab&#233; oeb &#193;be &#196;be &#212;eb &#225;be &#228;be &#244;eb.

    Here is the same list sorted by @sortBy compareUnicode@:

    Abe abe ab&#233; &#193;be &#225;be &#196;be &#228;be Oeb oeb &#212;eb &#244;eb

category:             Text
abi:                  632baa0778f952c914b733c5c2c95be4
exposed:              True
exposed-modules:      Data.RFC5051
hidden-modules:       Data.RFC5051.UnicodeData
import-dirs:          /usr/lib/ghc-8.10.1/site-local/rfc5051-0.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/rfc5051-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/rfc5051-0.2
hs-libraries:         HSrfc5051-0.2-7aXx1NTcmt9orSpjH8Jed
depends:              base-4.14.0.0 containers-0.6.2.1 text-1.2.3.2
haddock-interfaces:   /usr/share/doc/haskell-rfc5051/html/rfc5051.haddock
haddock-html:         /usr/share/doc/haskell-rfc5051/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
